@@ -36,9 +36,11 @@
 #include "GameLogic/goal.h"
 #include "SaveLoad/ksirkgamexmlloader.h"
 #include "Sprites/animspritesgroup.h"
-#include "Dialogs/jabbergameui.h"
 #include "Dialogs/kplayersetupwidget.h"
+#if HAVE_JABBER_SUPPORT
+#include "Dialogs/jabbergameui.h"
 #include "Jabber/kmessagejabber.h"
+#endif
 
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgame/kmessageserver.h>
@@ -47,6 +49,7 @@
 #include <fstream>
 
 // include files for QT
+#include <QRegExp>
 #include <QCursor>
 #include <QScrollBar>
 #include <QUuid>
@@ -82,7 +85,7 @@ void KGameWindow::mouseMoveEvent ( QMouseEvent * event )
   {
     return;
   }
-  mousePosGlobal = event->globalPos();
+  mousePosGlobal = event->globalPosition().toPoint();
   mousePos = m_frame->mapFromGlobal(mousePosGlobal);
   mousePosition = m_frame->mapToScene(mousePos);
   mouseLocalisation = clickIn(mousePosition);
@@ -393,12 +396,14 @@ void KGameWindow::slotArena(bool isCheck)
   }
 }
 
+#if HAVE_JABBER_SUPPORT
 void KGameWindow::slotJabberGame()
 {
   m_jabberGameWidget->init(m_automaton);
   m_jabberGameWidget->setPreviousGuiIndex(m_centralWidget->currentIndex());
   m_centralWidget->setCurrentIndex(JABBERGAME_INDEX);
 }
+#endif
 
 void KGameWindow::slotNewGame()
 {
@@ -406,10 +411,12 @@ void KGameWindow::slotNewGame()
   actionNewGame(GameAutomaton::None);
 }
 
+#if HAVE_JABBER_SUPPORT
 void KGameWindow::slotNewJabberGame()
 {
   actionNewGame(GameAutomaton::Jabber);
 }
+#endif
 
 void KGameWindow::slotNewSocketGame()
 {
@@ -464,7 +471,6 @@ void KGameWindow::slotSaveGame()
     QFile file(m_fileName);
     file.open(QIODevice::WriteOnly);
     QTextStream ofs(&file);
-    ofs.setCodec("UTF-8");
     saveXml(ofs);
     m_message->setMessageTimeout(3000);
     m_message->showMessage(i18n("Game saved to %1",m_fileName),
@@ -861,10 +867,12 @@ void KGameWindow::slotNewGameNext()
   m_automaton->newGameNext();
   m_reinitializingGame = false;
   
+#if HAVE_JABBER_SUPPORT
   if (m_automaton->networkGameType()==GameAutomaton::Jabber && m_jabberClient && m_jabberClient->isConnected())
   {
     sendGameInfoToJabber();
   }
+#endif
 }
 
 // void KGameWindow::slotNewGameOK(unsigned int nbPlayers, const QString& skin, unsigned int nbNetworkPlayers, bool useGoals)
@@ -897,6 +905,7 @@ void KGameWindow::slotNewGameKO()
   m_automaton->setGameStatus(KGame::Run);
 }
 
+#if HAVE_JABBER_SUPPORT
 void KGameWindow::slotConnected()
 {
   qCDebug(KSIRK_LOG) << "Connected to Jabber server.";
@@ -1128,6 +1137,7 @@ void KGameWindow::slotJabberGameCanceled(int previousIndex)
   qCDebug(KSIRK_LOG) << previousIndex;
   m_centralWidget->setCurrentIndex(previousIndex);
 }
+#endif
 
 void KGameWindow::slotExit()
 {
